from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Com.StructuredStorage
import win32more.Windows.Win32.System.SideShow
import win32more.Windows.Win32.UI.WindowsAndMessaging
class APPLICATION_EVENT_DATA(Structure):
    cbApplicationEventData: UInt32
    ApplicationId: Guid
    EndpointId: Guid
    dwEventId: UInt32
    cbEventData: UInt32
    bEventData: Byte * 1
    _pack_ = 1
SIDESHOW_ENDPOINT_SIMPLE_CONTENT_FORMAT: Guid = Guid('{a9a5353f-2d4b-47ce-93ee-759f3a7dda4f}')
SIDESHOW_ENDPOINT_ICAL: Guid = Guid('{4dff36b5-9dde-4f76-9a2a-96435047063d}')
SIDESHOW_CAPABILITY_DEVICE_PROPERTIES: Guid = Guid('{8abc88a8-857b-4ad7-a35a-b5942f492b99}')
SIDESHOW_CAPABILITY_DEVICE_ID: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{8abc88a8-857b-4ad7-a35a-b5942f492b99}'), pid=1)
SIDESHOW_CAPABILITY_SCREEN_TYPE: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{8abc88a8-857b-4ad7-a35a-b5942f492b99}'), pid=2)
SIDESHOW_CAPABILITY_SCREEN_WIDTH: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{8abc88a8-857b-4ad7-a35a-b5942f492b99}'), pid=3)
SIDESHOW_CAPABILITY_SCREEN_HEIGHT: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{8abc88a8-857b-4ad7-a35a-b5942f492b99}'), pid=4)
SIDESHOW_CAPABILITY_COLOR_DEPTH: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{8abc88a8-857b-4ad7-a35a-b5942f492b99}'), pid=5)
SIDESHOW_CAPABILITY_COLOR_TYPE: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{8abc88a8-857b-4ad7-a35a-b5942f492b99}'), pid=6)
SIDESHOW_CAPABILITY_DATA_CACHE: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{8abc88a8-857b-4ad7-a35a-b5942f492b99}'), pid=7)
SIDESHOW_CAPABILITY_SUPPORTED_LANGUAGES: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{8abc88a8-857b-4ad7-a35a-b5942f492b99}'), pid=8)
SIDESHOW_CAPABILITY_CURRENT_LANGUAGE: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{8abc88a8-857b-4ad7-a35a-b5942f492b99}'), pid=9)
SIDESHOW_CAPABILITY_SUPPORTED_THEMES: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{8abc88a8-857b-4ad7-a35a-b5942f492b99}'), pid=10)
SIDESHOW_CAPABILITY_SUPPORTED_IMAGE_FORMATS: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{8abc88a8-857b-4ad7-a35a-b5942f492b99}'), pid=14)
SIDESHOW_CAPABILITY_CLIENT_AREA_WIDTH: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{8abc88a8-857b-4ad7-a35a-b5942f492b99}'), pid=15)
SIDESHOW_CAPABILITY_CLIENT_AREA_HEIGHT: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{8abc88a8-857b-4ad7-a35a-b5942f492b99}'), pid=16)
GUID_DEVINTERFACE_SIDESHOW: Guid = Guid('{152e5811-feb9-4b00-90f4-d32947ae1681}')
SIDESHOW_CONTENT_MISSING_EVENT: Guid = Guid('{5007fba8-d313-439f-bea2-a50201d3e9a8}')
SIDESHOW_APPLICATION_EVENT: Guid = Guid('{4cb572fa-1d3b-49b3-a17a-2e6bff052854}')
SIDESHOW_USER_CHANGE_REQUEST_EVENT: Guid = Guid('{5009673c-3f7d-4c7e-9971-eaa2e91f1575}')
SIDESHOW_NEW_EVENT_DATA_AVAILABLE: Guid = Guid('{57813854-2fc1-411c-a59f-f24927608804}')
CONTENT_ID_GLANCE: UInt32 = 0
SIDESHOW_EVENTID_APPLICATION_ENTER: UInt32 = 4294901760
SIDESHOW_EVENTID_APPLICATION_EXIT: UInt32 = 4294901761
CONTENT_ID_HOME: UInt32 = 1
VERSION_1_WINDOWS_7: UInt32 = 0
class CONTENT_MISSING_EVENT_DATA(Structure):
    cbContentMissingEventData: UInt32
    ApplicationId: Guid
    EndpointId: Guid
    ContentId: UInt32
    _pack_ = 1
class DEVICE_USER_CHANGE_EVENT_DATA(Structure):
    cbDeviceUserChangeEventData: UInt32
    wszUser: Char
    _pack_ = 1
class EVENT_DATA_HEADER(Structure):
    cbEventDataHeader: UInt32
    guidEventType: Guid
    dwVersion: UInt32
    cbEventDataSid: UInt32
    _pack_ = 1
class ISideShowBulkCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.SideShow.ISideShowCapabilities
    _iid_ = Guid('{3a2b7fbc-3ad5-48bd-bbf1-0e6cfbd10807}')
    @commethod(4)
    def GetCapabilities(self, in_keyCollection: win32more.Windows.Win32.System.SideShow.ISideShowKeyCollection, inout_pValues: POINTER(win32more.Windows.Win32.System.SideShow.ISideShowPropVariantCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISideShowCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{535e1379-c09e-4a54-a511-597bab3a72b8}')
    @commethod(3)
    def GetCapability(self, in_keyCapability: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), inout_pValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISideShowCapabilitiesCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{50305597-5e0d-4ff7-b3af-33d0d9bd52dd}')
    @commethod(3)
    def GetCount(self, out_pdwCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetAt(self, in_dwIndex: UInt32, out_ppCapabilities: POINTER(win32more.Windows.Win32.System.SideShow.ISideShowCapabilities)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISideShowContent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c18552ed-74ff-4fec-be07-4cfed29d4887}')
    @commethod(3)
    def GetContent(self, in_pICapabilities: win32more.Windows.Win32.System.SideShow.ISideShowCapabilities, out_pdwSize: POINTER(UInt32), out_ppbData: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_ContentId(self, out_pcontentId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_DifferentiateContent(self, out_pfDifferentiateContent: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISideShowContentManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a5d5b66b-eef9-41db-8d7e-e17c33ab10b0}')
    @commethod(3)
    def Add(self, in_pIContent: win32more.Windows.Win32.System.SideShow.ISideShowContent) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Remove(self, in_contentId: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RemoveAll(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetEventSink(self, in_pIEvents: win32more.Windows.Win32.System.SideShow.ISideShowEvents) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetDeviceCapabilities(self, out_ppCollection: POINTER(win32more.Windows.Win32.System.SideShow.ISideShowCapabilitiesCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISideShowEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{61feca4c-deb4-4a7e-8d75-51f1132d615b}')
    @commethod(3)
    def ContentMissing(self, in_contentId: UInt32, out_ppIContent: POINTER(win32more.Windows.Win32.System.SideShow.ISideShowContent)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ApplicationEvent(self, in_pICapabilities: win32more.Windows.Win32.System.SideShow.ISideShowCapabilities, in_dwEventId: UInt32, in_dwEventSize: UInt32, in_pbEventData: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def DeviceAdded(self, in_pIDevice: win32more.Windows.Win32.System.SideShow.ISideShowCapabilities) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def DeviceRemoved(self, in_pIDevice: win32more.Windows.Win32.System.SideShow.ISideShowCapabilities) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISideShowKeyCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{045473bc-a37b-4957-b144-68105411ed8e}')
    @commethod(3)
    def Add(self, Key: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetAt(self, dwIndex: UInt32, pKey: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetCount(self, pcElems: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def RemoveAt(self, dwIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISideShowNotification(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{03c93300-8ab2-41c5-9b79-46127a30e148}')
    @commethod(3)
    def get_NotificationId(self, out_pNotificationId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def put_NotificationId(self, in_notificationId: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_Title(self, out_ppwszTitle: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def put_Title(self, in_pwszTitle: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def get_Message(self, out_ppwszMessage: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_Message(self, in_pwszMessage: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Image(self, out_phIcon: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_Image(self, in_hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_ExpirationTime(self, out_pTime: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_ExpirationTime(self, in_pTime: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISideShowNotificationManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{63cea909-f2b9-4302-b5e1-c68e6d9ab833}')
    @commethod(3)
    def Show(self, in_pINotification: win32more.Windows.Win32.System.SideShow.ISideShowNotification) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Revoke(self, in_notificationId: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RevokeAll(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISideShowPropVariantCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2ea7a549-7bff-4aae-bab0-22d43111de49}')
    @commethod(3)
    def Add(self, pValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetAt(self, dwIndex: UInt32, pValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetCount(self, pcElems: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def RemoveAt(self, dwIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISideShowSession(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e22331ee-9e7d-4922-9fc2-ab7aa41ce491}')
    @commethod(3)
    def RegisterContent(self, in_applicationId: POINTER(Guid), in_endpointId: POINTER(Guid), out_ppIContent: POINTER(win32more.Windows.Win32.System.SideShow.ISideShowContentManager)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def RegisterNotifications(self, in_applicationId: POINTER(Guid), out_ppINotification: POINTER(win32more.Windows.Win32.System.SideShow.ISideShowNotificationManager)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class NEW_EVENT_DATA_AVAILABLE(Structure):
    cbNewEventDataAvailable: UInt32
    dwVersion: UInt32
    _pack_ = 1
SCF_BUTTON_IDS = Int32
SCF_BUTTON_MENU: win32more.Windows.Win32.System.SideShow.SCF_BUTTON_IDS = 1
SCF_BUTTON_SELECT: win32more.Windows.Win32.System.SideShow.SCF_BUTTON_IDS = 2
SCF_BUTTON_UP: win32more.Windows.Win32.System.SideShow.SCF_BUTTON_IDS = 3
SCF_BUTTON_DOWN: win32more.Windows.Win32.System.SideShow.SCF_BUTTON_IDS = 4
SCF_BUTTON_LEFT: win32more.Windows.Win32.System.SideShow.SCF_BUTTON_IDS = 5
SCF_BUTTON_RIGHT: win32more.Windows.Win32.System.SideShow.SCF_BUTTON_IDS = 6
SCF_BUTTON_PLAY: win32more.Windows.Win32.System.SideShow.SCF_BUTTON_IDS = 7
SCF_BUTTON_PAUSE: win32more.Windows.Win32.System.SideShow.SCF_BUTTON_IDS = 8
SCF_BUTTON_FASTFORWARD: win32more.Windows.Win32.System.SideShow.SCF_BUTTON_IDS = 9
SCF_BUTTON_REWIND: win32more.Windows.Win32.System.SideShow.SCF_BUTTON_IDS = 10
SCF_BUTTON_STOP: win32more.Windows.Win32.System.SideShow.SCF_BUTTON_IDS = 11
SCF_BUTTON_BACK: win32more.Windows.Win32.System.SideShow.SCF_BUTTON_IDS = 65280
class SCF_CONTEXTMENU_EVENT(Structure):
    PreviousPage: UInt32
    TargetPage: UInt32
    PreviousItemId: UInt32
    MenuPage: UInt32
    MenuItemId: UInt32
class SCF_EVENT_HEADER(Structure):
    PreviousPage: UInt32
    TargetPage: UInt32
SCF_EVENT_IDS = Int32
SCF_EVENT_NAVIGATION: win32more.Windows.Win32.System.SideShow.SCF_EVENT_IDS = 1
SCF_EVENT_MENUACTION: win32more.Windows.Win32.System.SideShow.SCF_EVENT_IDS = 2
SCF_EVENT_CONTEXTMENU: win32more.Windows.Win32.System.SideShow.SCF_EVENT_IDS = 3
class SCF_MENUACTION_EVENT(Structure):
    PreviousPage: UInt32
    TargetPage: UInt32
    Button: UInt32
    ItemId: UInt32
class SCF_NAVIGATION_EVENT(Structure):
    PreviousPage: UInt32
    TargetPage: UInt32
    Button: UInt32
SIDESHOW_COLOR_TYPE = Int32
SIDESHOW_COLOR_TYPE_COLOR: win32more.Windows.Win32.System.SideShow.SIDESHOW_COLOR_TYPE = 0
SIDESHOW_COLOR_TYPE_GREYSCALE: win32more.Windows.Win32.System.SideShow.SIDESHOW_COLOR_TYPE = 1
SIDESHOW_COLOR_TYPE_BLACK_AND_WHITE: win32more.Windows.Win32.System.SideShow.SIDESHOW_COLOR_TYPE = 2
SIDESHOW_SCREEN_TYPE = Int32
SIDESHOW_SCREEN_TYPE_BITMAP: win32more.Windows.Win32.System.SideShow.SIDESHOW_SCREEN_TYPE = 0
SIDESHOW_SCREEN_TYPE_TEXT: win32more.Windows.Win32.System.SideShow.SIDESHOW_SCREEN_TYPE = 1
SideShowKeyCollection = Guid('{dfbbdbf8-18de-49b8-83dc-ebc727c62d94}')
SideShowNotification = Guid('{0ce3e86f-d5cd-4525-a766-1abab1a752f5}')
SideShowPropVariantCollection = Guid('{e640f415-539e-4923-96cd-5f093bc250cd}')
SideShowSession = Guid('{e20543b9-f785-4ea2-981e-c4ffa76bbc7c}')


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.UI
import win32more.Windows.UI.Notifications.Preview
import win32more.Windows.Win32.System.WinRT
class IToastOcclusionManagerPreviewStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Notifications.Preview.IToastOcclusionManagerPreviewStatics'
    _iid_ = Guid('{507e5c83-50f9-5412-8953-b65c18cfab12}')
    @winrt_commethod(6)
    def SetToastWindowMargin(self, appWindowId: win32more.Windows.UI.WindowId, margin: Double) -> Void: ...
class ToastOcclusionManagerPreview(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Notifications.Preview.ToastOcclusionManagerPreview'
    @winrt_classmethod
    def SetToastWindowMargin(cls: win32more.Windows.UI.Notifications.Preview.IToastOcclusionManagerPreviewStatics, appWindowId: win32more.Windows.UI.WindowId, margin: Double) -> Void: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.Media.PictureAcquisition
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Com.StructuredStorage
import win32more.Windows.Win32.UI.Shell.PropertiesSystem
import win32more.Windows.Win32.UI.WindowsAndMessaging
PKEY_PhotoAcquire_RelativePathname: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{00f23377-7ac6-4b7a-8443-345e731fa57a}'), pid=2)
PKEY_PhotoAcquire_FinalFilename: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{00f23377-7ac6-4b7a-8443-345e731fa57a}'), pid=3)
PKEY_PhotoAcquire_GroupTag: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{00f23377-7ac6-4b7a-8443-345e731fa57a}'), pid=4)
PKEY_PhotoAcquire_TransferResult: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{00f23377-7ac6-4b7a-8443-345e731fa57a}'), pid=5)
PKEY_PhotoAcquire_OriginalFilename: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{00f23377-7ac6-4b7a-8443-345e731fa57a}'), pid=6)
PKEY_PhotoAcquire_CameraSequenceNumber: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{00f23377-7ac6-4b7a-8443-345e731fa57a}'), pid=7)
PKEY_PhotoAcquire_IntermediateFile: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{00f23377-7ac6-4b7a-8443-345e731fa57a}'), pid=8)
PKEY_PhotoAcquire_SkipImport: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{00f23377-7ac6-4b7a-8443-345e731fa57a}'), pid=9)
PKEY_PhotoAcquire_DuplicateDetectionID: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{00f23377-7ac6-4b7a-8443-345e731fa57a}'), pid=10)
PROGRESS_INDETERMINATE: Int32 = -1
PHOTOACQ_ERROR_RESTART_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2147180543
PHOTOACQ_RUN_DEFAULT: UInt32 = 0
PHOTOACQ_NO_GALLERY_LAUNCH: UInt32 = 1
PHOTOACQ_DISABLE_AUTO_ROTATE: UInt32 = 2
PHOTOACQ_DISABLE_PLUGINS: UInt32 = 4
PHOTOACQ_DISABLE_GROUP_TAG_PROMPT: UInt32 = 8
PHOTOACQ_DISABLE_DB_INTEGRATION: UInt32 = 16
PHOTOACQ_DELETE_AFTER_ACQUIRE: UInt32 = 32
PHOTOACQ_DISABLE_DUPLICATE_DETECTION: UInt32 = 64
PHOTOACQ_ENABLE_THUMBNAIL_CACHING: UInt32 = 128
PHOTOACQ_DISABLE_METADATA_WRITE: UInt32 = 256
PHOTOACQ_DISABLE_THUMBNAIL_PROGRESS: UInt32 = 512
PHOTOACQ_DISABLE_SETTINGS_LINK: UInt32 = 1024
PHOTOACQ_ABORT_ON_SETTINGS_UPDATE: UInt32 = 2048
PHOTOACQ_IMPORT_VIDEO_AS_MULTIPLE_FILES: UInt32 = 4096
DSF_WPD_DEVICES: UInt32 = 1
DSF_WIA_CAMERAS: UInt32 = 2
DSF_WIA_SCANNERS: UInt32 = 4
DSF_STI_DEVICES: UInt32 = 8
DSF_TWAIN_DEVICES: UInt32 = 16
DSF_FS_DEVICES: UInt32 = 32
DSF_DV_DEVICES: UInt32 = 64
DSF_ALL_DEVICES: UInt32 = 65535
DSF_CPL_MODE: UInt32 = 65536
DSF_SHOW_OFFLINE: UInt32 = 131072
PAPS_PRESAVE: UInt32 = 0
PAPS_POSTSAVE: UInt32 = 1
PAPS_CLEANUP: UInt32 = 2
DEVICE_SELECTION_DEVICE_TYPE = Int32
DST_UNKNOWN_DEVICE: win32more.Windows.Win32.Media.PictureAcquisition.DEVICE_SELECTION_DEVICE_TYPE = 0
DST_WPD_DEVICE: win32more.Windows.Win32.Media.PictureAcquisition.DEVICE_SELECTION_DEVICE_TYPE = 1
DST_WIA_DEVICE: win32more.Windows.Win32.Media.PictureAcquisition.DEVICE_SELECTION_DEVICE_TYPE = 2
DST_STI_DEVICE: win32more.Windows.Win32.Media.PictureAcquisition.DEVICE_SELECTION_DEVICE_TYPE = 3
DSF_TWAIN_DEVICE: win32more.Windows.Win32.Media.PictureAcquisition.DEVICE_SELECTION_DEVICE_TYPE = 4
DST_FS_DEVICE: win32more.Windows.Win32.Media.PictureAcquisition.DEVICE_SELECTION_DEVICE_TYPE = 5
DST_DV_DEVICE: win32more.Windows.Win32.Media.PictureAcquisition.DEVICE_SELECTION_DEVICE_TYPE = 6
ERROR_ADVISE_MESSAGE_TYPE = Int32
PHOTOACQUIRE_ERROR_SKIPRETRYCANCEL: win32more.Windows.Win32.Media.PictureAcquisition.ERROR_ADVISE_MESSAGE_TYPE = 0
PHOTOACQUIRE_ERROR_RETRYCANCEL: win32more.Windows.Win32.Media.PictureAcquisition.ERROR_ADVISE_MESSAGE_TYPE = 1
PHOTOACQUIRE_ERROR_YESNO: win32more.Windows.Win32.Media.PictureAcquisition.ERROR_ADVISE_MESSAGE_TYPE = 2
PHOTOACQUIRE_ERROR_OK: win32more.Windows.Win32.Media.PictureAcquisition.ERROR_ADVISE_MESSAGE_TYPE = 3
ERROR_ADVISE_RESULT = Int32
PHOTOACQUIRE_RESULT_YES: win32more.Windows.Win32.Media.PictureAcquisition.ERROR_ADVISE_RESULT = 0
PHOTOACQUIRE_RESULT_NO: win32more.Windows.Win32.Media.PictureAcquisition.ERROR_ADVISE_RESULT = 1
PHOTOACQUIRE_RESULT_OK: win32more.Windows.Win32.Media.PictureAcquisition.ERROR_ADVISE_RESULT = 2
PHOTOACQUIRE_RESULT_SKIP: win32more.Windows.Win32.Media.PictureAcquisition.ERROR_ADVISE_RESULT = 3
PHOTOACQUIRE_RESULT_SKIP_ALL: win32more.Windows.Win32.Media.PictureAcquisition.ERROR_ADVISE_RESULT = 4
PHOTOACQUIRE_RESULT_RETRY: win32more.Windows.Win32.Media.PictureAcquisition.ERROR_ADVISE_RESULT = 5
PHOTOACQUIRE_RESULT_ABORT: win32more.Windows.Win32.Media.PictureAcquisition.ERROR_ADVISE_RESULT = 6
class IPhotoAcquire(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00f23353-e31b-4955-a8ad-ca5ebf31e2ce}')
    @commethod(3)
    def CreatePhotoSource(self, pszDevice: win32more.Windows.Win32.Foundation.PWSTR, ppPhotoAcquireSource: POINTER(win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireSource)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Acquire(self, pPhotoAcquireSource: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireSource, fShowProgress: win32more.Windows.Win32.Foundation.BOOL, hWndParent: win32more.Windows.Win32.Foundation.HWND, pszApplicationName: win32more.Windows.Win32.Foundation.PWSTR, pPhotoAcquireProgressCB: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireProgressCB) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def EnumResults(self, ppEnumFilePaths: POINTER(win32more.Windows.Win32.System.Com.IEnumString)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPhotoAcquireDeviceSelectionDialog(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00f28837-55dd-4f37-aaf5-6855a9640467}')
    @commethod(3)
    def SetTitle(self, pszTitle: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetSubmitButtonText(self, pszSubmitButtonText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def DoModal(self, hWndParent: win32more.Windows.Win32.Foundation.HWND, dwDeviceFlags: UInt32, pbstrDeviceId: POINTER(win32more.Windows.Win32.Foundation.BSTR), pnDeviceType: POINTER(win32more.Windows.Win32.Media.PictureAcquisition.DEVICE_SELECTION_DEVICE_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPhotoAcquireItem(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00f21c97-28bf-4c02-b842-5e4e90139a30}')
    @commethod(3)
    def GetItemName(self, pbstrItemName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetThumbnail(self, sizeThumbnail: win32more.Windows.Win32.Foundation.SIZE, phbmpThumbnail: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetProperty(self, key: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), pv: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetProperty(self, key: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), pv: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetStream(self, ppStream: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CanDelete(self, pfCanDelete: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Delete(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetSubItemCount(self, pnCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetSubItemAt(self, nItemIndex: UInt32, ppPhotoAcquireItem: POINTER(win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPhotoAcquireOptionsDialog(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00f2b3ee-bf64-47ee-89f4-4dedd79643f2}')
    @commethod(3)
    def Initialize(self, pszRegistryRoot: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Create(self, hWndParent: win32more.Windows.Win32.Foundation.HWND, phWndDialog: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Destroy(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def DoModal(self, hWndParent: win32more.Windows.Win32.Foundation.HWND, ppnReturnCode: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SaveData(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPhotoAcquirePlugin(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00f2dceb-ecb8-4f77-8e47-e7a987c83dd0}')
    @commethod(3)
    def Initialize(self, pPhotoAcquireSource: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireSource, pPhotoAcquireProgressCB: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireProgressCB) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ProcessItem(self, dwAcquireStage: UInt32, pPhotoAcquireItem: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireItem, pOriginalItemStream: win32more.Windows.Win32.System.Com.IStream, pszFinalFilename: win32more.Windows.Win32.Foundation.PWSTR, pPropertyStore: win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def TransferComplete(self, hr: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def DisplayConfigureDialog(self, hWndParent: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPhotoAcquireProgressCB(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00f2ce1e-935e-4248-892c-130f32c45cb4}')
    @commethod(3)
    def Cancelled(self, pfCancelled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def StartEnumeration(self, pPhotoAcquireSource: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireSource) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def FoundItem(self, pPhotoAcquireItem: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireItem) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def EndEnumeration(self, hr: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def StartTransfer(self, pPhotoAcquireSource: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireSource) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def StartItemTransfer(self, nItemIndex: UInt32, pPhotoAcquireItem: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireItem) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def DirectoryCreated(self, pszDirectory: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def UpdateTransferPercent(self, fOverall: win32more.Windows.Win32.Foundation.BOOL, nPercent: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def EndItemTransfer(self, nItemIndex: UInt32, pPhotoAcquireItem: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireItem, hr: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def EndTransfer(self, hr: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def StartDelete(self, pPhotoAcquireSource: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireSource) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def StartItemDelete(self, nItemIndex: UInt32, pPhotoAcquireItem: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireItem) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def UpdateDeletePercent(self, nPercent: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def EndItemDelete(self, nItemIndex: UInt32, pPhotoAcquireItem: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireItem, hr: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def EndDelete(self, hr: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def EndSession(self, hr: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetDeleteAfterAcquire(self, pfDeleteAfterAcquire: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def ErrorAdvise(self, hr: win32more.Windows.Win32.Foundation.HRESULT, pszErrorMessage: win32more.Windows.Win32.Foundation.PWSTR, nMessageType: win32more.Windows.Win32.Media.PictureAcquisition.ERROR_ADVISE_MESSAGE_TYPE, pnErrorAdviseResult: POINTER(win32more.Windows.Win32.Media.PictureAcquisition.ERROR_ADVISE_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetUserInput(self, riidType: POINTER(Guid), pUnknown: win32more.Windows.Win32.System.Com.IUnknown, pPropVarResult: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT), pPropVarDefault: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPhotoAcquireSettings(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00f2b868-dd67-487c-9553-049240767e91}')
    @commethod(3)
    def InitializeFromRegistry(self, pszRegistryKey: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetFlags(self, dwPhotoAcquireFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetOutputFilenameTemplate(self, pszTemplate: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetSequencePaddingWidth(self, dwWidth: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetSequenceZeroPadding(self, fZeroPad: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetGroupTag(self, pszGroupTag: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetAcquisitionTime(self, pftAcquisitionTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetFlags(self, pdwPhotoAcquireFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetOutputFilenameTemplate(self, pbstrTemplate: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetSequencePaddingWidth(self, pdwWidth: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetSequenceZeroPadding(self, pfZeroPad: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetGroupTag(self, pbstrGroupTag: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetAcquisitionTime(self, pftAcquisitionTime: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPhotoAcquireSource(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00f2c703-8613-4282-a53b-6ec59c5883ac}')
    @commethod(3)
    def GetFriendlyName(self, pbstrFriendlyName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDeviceIcons(self, nSize: UInt32, phLargeIcon: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON), phSmallIcon: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def InitializeItemList(self, fForceEnumeration: win32more.Windows.Win32.Foundation.BOOL, pPhotoAcquireProgressCB: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireProgressCB, pnItemCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetItemCount(self, pnItemCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetItemAt(self, nIndex: UInt32, ppPhotoAcquireItem: POINTER(win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetPhotoAcquireSettings(self, ppPhotoAcquireSettings: POINTER(win32more.Windows.Win32.Media.PictureAcquisition.IPhotoAcquireSettings)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetDeviceId(self, pbstrDeviceId: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def BindToObject(self, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPhotoProgressActionCB(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00f242d0-b206-4e7d-b4c1-4755bcbb9c9f}')
    @commethod(3)
    def DoAction(self, hWndParent: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPhotoProgressDialog(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00f246f9-0750-4f08-9381-2cd8e906a4ae}')
    @commethod(3)
    def Create(self, hwndParent: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetWindow(self, phwndProgressDialog: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Destroy(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetTitle(self, pszTitle: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ShowCheckbox(self, nCheckboxId: win32more.Windows.Win32.Media.PictureAcquisition.PROGRESS_DIALOG_CHECKBOX_ID, fShow: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetCheckboxText(self, nCheckboxId: win32more.Windows.Win32.Media.PictureAcquisition.PROGRESS_DIALOG_CHECKBOX_ID, pszCheckboxText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetCheckboxCheck(self, nCheckboxId: win32more.Windows.Win32.Media.PictureAcquisition.PROGRESS_DIALOG_CHECKBOX_ID, fChecked: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetCheckboxTooltip(self, nCheckboxId: win32more.Windows.Win32.Media.PictureAcquisition.PROGRESS_DIALOG_CHECKBOX_ID, pszCheckboxTooltipText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def IsCheckboxChecked(self, nCheckboxId: win32more.Windows.Win32.Media.PictureAcquisition.PROGRESS_DIALOG_CHECKBOX_ID, pfChecked: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetCaption(self, pszTitle: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetImage(self, nImageType: win32more.Windows.Win32.Media.PictureAcquisition.PROGRESS_DIALOG_IMAGE_TYPE, hIcon: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON, hBitmap: win32more.Windows.Win32.Graphics.Gdi.HBITMAP) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetPercentComplete(self, nPercent: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetProgressText(self, pszProgressText: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetActionLinkCallback(self, pPhotoProgressActionCB: win32more.Windows.Win32.Media.PictureAcquisition.IPhotoProgressActionCB) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def SetActionLinkText(self, pszCaption: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def ShowActionLink(self, fShow: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def IsCancelled(self, pfCancelled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetUserInput(self, riidType: POINTER(Guid), pUnknown: win32more.Windows.Win32.System.Com.IUnknown, pPropVarResult: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT), pPropVarDefault: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUserInputString(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{00f243a1-205b-45ba-ae26-abbc53aa7a6f}')
    @commethod(3)
    def GetSubmitButtonText(self, pbstrSubmitButtonText: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetPrompt(self, pbstrPromptTitle: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetStringId(self, pbstrStringId: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetStringType(self, pnStringType: POINTER(win32more.Windows.Win32.Media.PictureAcquisition.USER_INPUT_STRING_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetTooltipText(self, pbstrTooltipText: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetMaxLength(self, pcchMaxLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetDefault(self, pbstrDefault: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetMruCount(self, pnMruCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetMruEntryAt(self, nIndex: UInt32, pbstrMruEntry: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetImage(self, nSize: UInt32, phBitmap: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP), phIcon: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
PROGRESS_DIALOG_CHECKBOX_ID = Int32
PROGRESS_DIALOG_CHECKBOX_ID_DEFAULT: win32more.Windows.Win32.Media.PictureAcquisition.PROGRESS_DIALOG_CHECKBOX_ID = 0
PROGRESS_DIALOG_IMAGE_TYPE = Int32
PROGRESS_DIALOG_ICON_SMALL: win32more.Windows.Win32.Media.PictureAcquisition.PROGRESS_DIALOG_IMAGE_TYPE = 0
PROGRESS_DIALOG_ICON_LARGE: win32more.Windows.Win32.Media.PictureAcquisition.PROGRESS_DIALOG_IMAGE_TYPE = 1
PROGRESS_DIALOG_ICON_THUMBNAIL: win32more.Windows.Win32.Media.PictureAcquisition.PROGRESS_DIALOG_IMAGE_TYPE = 2
PROGRESS_DIALOG_BITMAP_THUMBNAIL: win32more.Windows.Win32.Media.PictureAcquisition.PROGRESS_DIALOG_IMAGE_TYPE = 3
PhotoAcquire = Guid('{00f26e02-e9f2-4a9f-9fdd-5a962fb26a98}')
PhotoAcquireAutoPlayDropTarget = Guid('{00f20eb5-8fd6-4d9d-b75e-36801766c8f1}')
PhotoAcquireAutoPlayHWEventHandler = Guid('{00f2b433-44e4-4d88-b2b0-2698a0a91dba}')
PhotoAcquireDeviceSelectionDialog = Guid('{00f29a34-b8a1-482c-bcf8-3ac7b0fe8f62}')
PhotoAcquireOptionsDialog = Guid('{00f210a1-62f0-438b-9f7e-9618d72a1831}')
PhotoProgressDialog = Guid('{00f24ca0-748f-4e8a-894f-0e0357c6799f}')
USER_INPUT_STRING_TYPE = Int32
USER_INPUT_DEFAULT: win32more.Windows.Win32.Media.PictureAcquisition.USER_INPUT_STRING_TYPE = 0
USER_INPUT_PATH_ELEMENT: win32more.Windows.Win32.Media.PictureAcquisition.USER_INPUT_STRING_TYPE = 1


make_ready(__name__)
